@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-13 16:49:46
-@LastEditTime: 2021-10-12 17:48:53
+@LastEditTime: 2021-11-10 18:13:48
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -258,7 +258,7 @@ class TiktokVoucherOrderHandler(ClientBaseHandler):
             if invoke_result_data.success == True:
                 pay_notify_url = invoke_result_data.data["pay_notify_url"] if invoke_result_data.data.__contains__("pay_notify_url") else pay_notify_url
                 time_expire = invoke_result_data.data["time_expire"] if invoke_result_data.data.__contains__("time_expire") else 3600  #交易结束时间,设置1小时,单位秒
-            invoke_result_data = TikTokPayRequest().create_order(out_order_no=pay_order_no, notify_url=pay_notify_url, total_amount=total_amount, subject=subject, body=body, valid_time=time_expire)
+            invoke_result_data = TikTokPayRequest().create_order(pay_order_no=pay_order_no, notify_url=pay_notify_url, total_amount=total_amount, subject=subject, body=body, valid_time=time_expire)
             if invoke_result_data.success == False:
                 return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
             # self.logging_link_info('小程序支付返回前端参数:' + str(invoke_result_data.data))
@@ -311,8 +311,7 @@ class TiktokPayNotifyHandler(FrameBaseHandler):
             if response_result["type"] != "payment":
                 return self.write(tiktok_reponse.convert_response_json(-1, "回调类型标记错误"))
             response_data = SevenHelper.json_loads(response_result["msg"])
-            extra = SevenHelper.json_loads(response_data["extra"])
-            total_fee = extra["share_amount"] if extra.__contains__("share_amount") else 0
+            total_fee = response_data["total_amount"] if response_data.__contains__("total_amount") else 0
             pay_order_no = response_data["cp_orderno"]
             pay_order_model = PayOrderModel(context=self)
             pay_order = pay_order_model.get_entity("pay_order_no=%s", params=[pay_order_no])
