@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-10 11:29:31
-@LastEditTime: 2021-09-17 17:53:57
+@LastEditTime: 2021-10-10 15:39:51
 @LastEditors: HuangJianYi
 @Description: 处理数据统计上报
 """
@@ -15,8 +15,6 @@ class ShareReportHandler(ClientBaseHandler):
     :description: 处理分享上报
     """
     @filter_check_params("act_id,tb_user_id,login_token")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理分享上报
@@ -86,8 +84,6 @@ class InviteReportHandler(ClientBaseHandler):
     :description: 处理邀请进入上报
     """
     @filter_check_params("act_id,tb_user_id,login_token")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理分享上报
