@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2021-10-13 09:51:18
+@LastEditTime: 2021-10-28 11:26:12
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -85,7 +85,7 @@ class ReceiveRewardHandler(ClientBaseHandler):
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
-        task_id = int(self.get_param("task_id"),0)
+        task_id = int(self.get_param("task_id", 0))
         task_sub_type = self.get_param("task_sub_type")
         task_base_model = TaskBaseModel(context=self)
         invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token, task_id, task_sub_type, self.request_params)
