@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2021-10-11 17:53:30
+@LastEditTime: 2021-11-05 14:40:38
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -14,7 +14,8 @@ from seven_cloudapp_frame.models.app_base_model import *
 from seven_cloudapp_frame.models.asset_base_model import *
 from seven_cloudapp_frame.models.top_base_model import *
 from seven_cloudapp_frame.models.db_models.tao.tao_coupon_model import *
-
+from seven_cloudapp_frame.libs.customize.wechat_helper import *
+from seven_cloudapp_frame.libs.customize.tiktok_helper import *
 
 class LoginHandler(ClientBaseHandler):
     """
@@ -36,6 +37,9 @@ class LoginHandler(ClientBaseHandler):
         act_id = int(self.get_param("act_id", 0))
         module_id = int(self.get_param("module_id", 0))
         avatar = self.get_param("avatar")
+        code = self.get_param("code", "")
+        anonymous_code = self.get_param("anonymous_code", "")
+        pt = self.get_param("pt", "tb")  #tb淘宝 tt抖音 wx微信 qq h5
 
         app_base_model = AppBaseModel(context=self)
         app_info_dict = app_base_model.get_app_info_dict(app_id)
@@ -49,10 +53,22 @@ class LoginHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
 
+        if pt == "wx" and code:
+            invoke_result_data = WeChatHelper.code2_session(code, app_id=config.get_value("app_id"), app_secret=config.get_value("app_secret"))
+            if invoke_result_data.success == False:
+                return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+            open_id =  invoke_result_data.data["openid"]
+        elif pt == "tt" and code:
+            invoke_result_data = TikTokHelper.code2_session(code, anonymous_code, app_id=config.get_value("app_id"), app_secret=config.get_value("app_secret"))
+            if invoke_result_data.success == False:
+                return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+            open_id = invoke_result_data.data["openid"]
+
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, user_nick, avatar)
+        invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, self.emoji_to_emoji_base64(user_nick), avatar)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        invoke_result_data.data["user_nick"] = self.emoji_base64_to_emoji(invoke_result_data.data["user_nick"])
         invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, module_id, open_id, user_nick, avatar)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -119,7 +135,7 @@ class UpdateUserInfoHandler(ClientBaseHandler):
 
         invoke_result_data = InvokeResultData()
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = user_base_model.update_user_info(app_id, act_id, user_id, open_id, user_nick, avatar, is_member_before, is_favor_before)
+        invoke_result_data = user_base_model.update_user_info(app_id, act_id, user_id, open_id, self.emoji_to_emoji_base64(user_nick), avatar, is_member_before, is_favor_before)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         else:
@@ -313,3 +329,61 @@ class GetJoinMemberUrlHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
+
+
+class UserAddressListHandler(ClientBaseHandler):
+    """
+    :description: 收货地址列表
+    """
+    @filter_check_params("act_id,tb_user_id")
+    def get_async(self):
+        """
+        :param act_id：活动标识
+        :param tb_user_id：用户标识
+        :return: list
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_source_app_id()
+        act_id = int(self.get_param("act_id", 0))
+        open_id = self.get_param("open_id")
+        user_id = self.get_user_id()
+        user_base_model = UserBaseModel(context=self)
+        return self.response_json_success(user_base_model.get_user_address_list(app_id, act_id, user_id))
+
+
+class SaveUserAddressHandler(ClientBaseHandler):
+    """
+    :description: 保存收货地址
+    """
+    @filter_check_params("act_id,tb_user_id,real_name,telephone")
+    def get_async(self):
+        """
+        :param act_id：活动标识
+        :param tb_user_id：用户标识
+        :param is_default：是否默认地址（1是0否）
+        :param real_name：真实姓名
+        :param telephone：手机号码
+        :param province：省
+        :param city：市
+        :param county：区
+        :param street：街道
+        :param adress：地址
+        :return: dict
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_source_app_id()
+        act_id = int(self.get_param("act_id", 0))
+        user_id = self.get_user_id()
+        open_id = self.get_param("open_id")
+        user_address_id = int(self.get_param("user_address_id", 0))
+        real_name = self.get_param("real_name")
+        telephone = self.get_param("telephone")
+        province = self.get_param("province")
+        city = self.get_param("city")
+        county = self.get_param("county")
+        street = self.get_param("street")
+        address = self.get_param("address")
+        is_default = int(self.get_param("is_default", 0))
+
+        user_base_model = UserBaseModel(context=self)
+        return self.response_json_success(user_base_model.save_user_address(app_id, act_id, user_id, open_id, user_address_id, real_name, telephone, province, city, county, street, address, is_default))
