@@ -1,8 +1,16 @@
 # -*- coding: utf-8 -*-
 """
+@Author: HuangJianYi
+@Date: 2021-07-15 11:30:45
+@LastEditTime: 2021-11-11 16:30:31
+@LastEditors: HuangJianYi
+@Description: 
+"""
+# -*- coding: utf-8 -*-
+"""
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-10-15 11:36:45
+@LastEditTime: 2021-11-01 18:27:35
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -18,6 +26,7 @@ from seven_framework.redis import *
 from seven_framework.web_tornado.base_handler.base_api_handler import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.libs.customize.cryptography_helper import *
+from seven_cloudapp_frame.libs.customize.string_helper import *
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.models.user_base_model import *
 from seven_cloudapp_frame.models.db_models.app.app_info_model import *
@@ -29,6 +38,20 @@ class FrameBaseHandler(BaseApiHandler):
     """
     :description: 公共handler基类
     """
+    def get_http_log_extra_dict(self):
+        """
+        :Description: 获取http日志参数字典
+        :last_editors: HuangJianYi
+        """
+        dict_param = {}
+        dict_param["open_id"] = self.get_open_id()
+        if not dict_param["open_id"]:
+            dict_param["open_id"] = self.get_user_id()
+        dict_param["nick_name"] = self.get_user_nick()
+        dict_param["app_id"] = self.get_app_id()
+        if not dict_param["app_id"]:
+            dict_param["app_id"] = self.get_source_app_id()
+        return dict_param
 
     def prepare(self):
         """
@@ -41,14 +64,7 @@ class FrameBaseHandler(BaseApiHandler):
         #获取请求参数
         self._convert_request_params()
         # 标记日志请求关联
-        dict_param = {}
-        dict_param["open_id"] = self.get_open_id()
-        if not dict_param["open_id"]:
-            dict_param["open_id"] = self.get_user_id()
-        dict_param["nick_name"] = self.get_user_nick()
-        dict_param["app_id"] = self.get_app_id()
-        if not dict_param["app_id"]:
-            dict_param["app_id"] = self.get_source_app_id()
+        dict_param = self.get_http_log_extra_dict()
         self._build_http_log(dict_param)
 
     def options_async(self):
@@ -75,11 +91,13 @@ class FrameBaseHandler(BaseApiHandler):
         """
         return SevenHelper.json_loads(rep_str)
 
-    def get_param(self, param_name, default="", strip=True):
+    def get_param(self, param_name, default="", strip=True, filter_sql=False, filter_special_key=False):
         """
         :description: 二次封装获取参数
         :param param_name: 参数名
         :param default: 如果无此参数，则返回默认值
+        :param filter_sql: 是否过滤sql关键字
+        :param filter_special_key: 是否过滤sql特殊字符
         :return: 参数值
         :last_editors: HuangJianYi
         """
@@ -91,8 +109,76 @@ class FrameBaseHandler(BaseApiHandler):
             param_ret = self.get_argument(param_name, default, strip=strip)
         if param_ret == "" or param_ret == "undefined":
             param_ret = default
+        if filter_sql == True:
+            param_ret = StringHelper.filter_sql(param_ret)
+        if filter_special_key == True:
+            param_ret = StringHelper.filter_special_key(param_ret)
         return param_ret
 
+    def _convert_request_params(self):
+        """
+        :Description: 转换请求参数
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        self.request_params = {}
+        client_encrypt_type = config.get_value("client_encrypt_type", 0)  #客户端加密类型 0-无，1-aes加密，2-md5加密
+        server_encrypt_type = config.get_value("server_encrypt_type", 0)  #千牛端或后台加密类型 0-无，1-aes加密，2-md5加密
+        is_encrypt = False if hasattr(self, "is_encrypt") and self.is_encrypt == False else True
+        if is_encrypt == True and ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
+            encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
+            app_id = self.get_argument("source_app_id", "", strip=True)
+            if not app_id:
+                app_id = config.get_value("app_id")
+            password = str(encrypt_key).replace("1", "l")
+            if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
+                try:
+                    json_params = json.loads(self.request.body)
+                    if json_params:
+                        for field in json_params:
+                            self.request_params[field] = json_params[field]
+                        par = json_params["par"] if json_params.__contains__("par") else ""
+                        dv = json_params["dv"] if json_params.__contains__("dv") else ""
+                        iv = app_id[0:10] + str(json_params["dv"])[0:6] if len(str(json_params["dv"])) >= 6 else ""
+                        body_params = json.loads(CryptographyHelper.aes_decrypt(str(json_params["par"]), password, iv))
+                        for field in body_params:
+                            self.request_params[field] = body_params[field]
+                except:
+                    invoke_result_data.success = False
+                    invoke_result_data.error_code = "error"
+                    invoke_result_data.error_message = "参数解析错误"
+                    return invoke_result_data
+            else:
+                for field in self.request.arguments:
+                    self.request_params[field] = self.get_argument(field, "", strip=True)
+                if "par" in self.request.arguments and "dv" in self.request.arguments:
+                    par = self.get_argument("par", "", strip=True)
+                    dv = self.get_argument("dv", "", strip=True)
+                    iv = app_id[0:10] + str(dv)[0:6] if len(str(dv)) >= 6 else ""
+                    try:
+                        body_params = json.loads(CryptographyHelper.aes_decrypt(par, password, iv))
+                        for field in body_params:
+                            self.request_params[field] = body_params[field]
+                    except:
+                        invoke_result_data.success = False
+                        invoke_result_data.error_code = "error"
+                        invoke_result_data.error_message = "参数解析错误"
+                        return invoke_result_data
+        else:
+            if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
+                try:
+                    json_params = json.loads(self.request.body)
+                except:
+                    pass
+                if json_params:
+                    for field in json_params:
+                        self.request_params[field] = json_params[field]
+            else:
+                for field in self.request.arguments:
+                    self.request_params[field] = self.get_argument(field, "", strip=True)
+
+        return invoke_result_data
+
     def response_custom(self, rep_dic):
         """
         :description: 输出公共json模型
@@ -227,19 +313,26 @@ class FrameBaseHandler(BaseApiHandler):
         """
         result = False, ""
         if object_id and handler_name and app_id:
-            request_param_dict = {}
-            try:
-                if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
-                    request_param_dict = json.loads(self.request.body)
-                else:
-                    request_param_dict = dict([(k, v[0]) for k, v in parse_qs(self.request.query, True).items()])
-            except:
-                pass
-            sign = self.get_signature_md5(request_param_dict)
+            sign = self.get_signature_md5(self.request_params)
             if SevenHelper.is_continue_request(f"continue_request:{handler_name}_{app_id}_{object_id}_{sign}", expire) == True:
                 result = True, f"操作太频繁,请{expire}毫秒后再试"
         return result
 
+    def check_attack_request(self):
+        """
+        :description: 攻击请求校验
+        :return:满足条件直接拦截
+        :last_editors: HuangJianYi
+        """
+        result = False, ""
+        is_filter_attack = config.get_value("is_filter_attack", False)
+        if is_filter_attack == True and self.request_params:
+            for key in self.request_params.keys():
+                if StringHelper.is_contain_sql(self.request_params[key]) or StringHelper.is_attack(self.request_params[key]):
+                    result = True, f"参数{key}:值不合法"
+                    break
+        return result
+
     def get_signature_md5(self, request_param_dict, encrypt_key=""):
         """
         :description: 参数按照加密规则进行MD5加密
@@ -445,70 +538,6 @@ class FrameBaseHandler(BaseApiHandler):
 
         operation_log_model.add_entity(operation_log)
 
-    def _convert_request_params(self):
-        """
-        :Description: 转换请求参数
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        self.request_params = {}
-        client_encrypt_type = config.get_value("client_encrypt_type", 0)  #客户端加密类型 0-无，1-aes加密，2-md5加密
-        server_encrypt_type = config.get_value("server_encrypt_type", 0)  #千牛端或后台加密类型 0-无，1-aes加密，2-md5加密
-        is_encrypt = False if hasattr(self, "is_encrypt") and self.is_encrypt == False else True
-        if is_encrypt == True and ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
-            encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
-            app_id = self.get_argument("source_app_id", "", strip=True)
-            if not app_id:
-                app_id = config.get_value("app_id")
-            password = str(encrypt_key).replace("1", "l")
-            if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
-                try:
-                    json_params = json.loads(self.request.body)
-                    if json_params:
-                        for field in json_params:
-                            self.request_params[field] = json_params[field]
-                        par = json_params["par"] if json_params.__contains__("par") else ""
-                        dv = json_params["dv"] if json_params.__contains__("dv") else ""
-                        iv = app_id[0:10] + str(json_params["dv"])[0:6] if len(str(json_params["dv"])) >= 6 else ""
-                        body_params = json.loads(CryptographyHelper.aes_decrypt(str(json_params["par"]), password, iv))
-                        for field in body_params:
-                            self.request_params[field] = body_params[field]
-                except:
-                    invoke_result_data.success = False
-                    invoke_result_data.error_code = "error"
-                    invoke_result_data.error_message = "参数解析错误"
-                    return invoke_result_data
-            else:
-                for field in self.request.arguments:
-                    self.request_params[field] = self.get_argument(field, "", strip=True)
-                if "par" in self.request.arguments and "dv" in self.request.arguments:
-                    par = self.get_argument("par", "", strip=True)
-                    dv = self.get_argument("dv", "", strip=True)
-                    iv = app_id[0:10] + str(dv)[0:6] if len(str(dv)) >= 6 else ""
-                    try:
-                        body_params = json.loads(CryptographyHelper.aes_decrypt(par, password, iv))
-                        for field in body_params:
-                            self.request_params[field] = body_params[field]
-                    except:
-                        invoke_result_data.success = False
-                        invoke_result_data.error_code = "error"
-                        invoke_result_data.error_message = "参数解析错误"
-                        return invoke_result_data
-        else:
-            if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
-                try:
-                    json_params = json.loads(self.request.body)
-                except:
-                    pass
-                if json_params:
-                    for field in json_params:
-                        self.request_params[field] = json_params[field]
-            else:
-                for field in self.request.arguments:
-                    self.request_params[field] = self.get_argument(field, "", strip=True)
-
-        return invoke_result_data
-
 
 class ClientBaseHandler(FrameBaseHandler):
     """
@@ -520,9 +549,11 @@ class ClientBaseHandler(FrameBaseHandler):
         :Description: 置于任何请求方法前被调用(请勿重写此函数,可重写prepare_ext)
         :last_editors: HuangJianYi
         """
+
         if self.__class__.__name__ == "IndexHandler":
             return
-        #获取请求参数
+
+        #获取并转换请求参数
         invoke_result_data = self._convert_request_params()
         if invoke_result_data.success == False:
             self.request_code = UUIDHelper.get_uuid()
@@ -530,24 +561,20 @@ class ClientBaseHandler(FrameBaseHandler):
             self.finish()
             return
 
-        dict_param = {}
-        dict_param["open_id"] = self.get_open_id()
-        if not dict_param["open_id"]:
-            dict_param["open_id"] = self.get_user_id()
-        dict_param["nick_name"] = self.get_user_nick()
-        dict_param["app_id"] = self.get_app_id()
-        if not dict_param["app_id"]:
-            dict_param["app_id"] = self.get_source_app_id()
-
-        # 标记日志请求关联
-        self._build_http_log(dict_param)
-
         try:
-            # 将设备信息字符串转为字典类型
-            self.device_info_dict = {}
-            clientheaderinfo_string = self.request.headers._dict.get("Clientheaderinfo")
-            if clientheaderinfo_string:
-                self.device_info_dict = self.get_device_info_dict(clientheaderinfo_string)
+            # 标记日志请求关联
+            dict_param = self.get_http_log_extra_dict()
+            self._build_http_log(dict_param)
+
+            # 获取设备信息
+            self.device_info_dict = self.get_device_info_dict()
+
+            # 防攻击校验
+            is_attack_request, error_message = self.check_attack_request()
+            if is_attack_request:
+                self.response_json_error("error", error_message)
+                self.finish()
+                return
 
             # 验证超时 10分钟过期
             client_encrypt_type = config.get_value("client_encrypt_type", 0)
@@ -604,26 +631,27 @@ class ClientBaseHandler(FrameBaseHandler):
         live_url = f"https://market.m.taobao.com/app/taefed/shopping-delivery-wapp/index.html#/putin?mainKey=form&appId={app_id}"
         return live_url
 
-    def get_device_info_dict(self, device_str):
+    def get_device_info_dict(self):
         """
         :description: 获取头部参数字典
-        :param device_string:头部信息串
         :last_editors: HuangJianYi
         """
         device_info_dict = {}
-        info_model = parse_qs(device_str)
-        device_info_dict["pid"] = int(info_model["pid"][0])  # 产品标识
-        device_info_dict["chid"] = 0 if "chid" not in info_model.keys() else int(info_model["chid"][0])  # 渠道标识
-        device_info_dict["height"] = 0 if "height" not in info_model.keys() else int(info_model["height"][0])  # 高度
-        device_info_dict["width"] = 0 if "width" not in info_model.keys() else int(info_model["width"][0])  # 宽度
-        device_info_dict["version"] = "" if "version" not in info_model.keys() else info_model["version"][0]  # 客户端版本号
-        device_info_dict["app_version"] = "" if "app_version" not in info_model.keys() else info_model["app_version"][0]  # 小程序版本号
-        device_info_dict["net"] = "" if "net" not in info_model.keys() else info_model["net"][0]  # 网络
-        device_info_dict["model_p"] = "" if "model" not in info_model.keys() else info_model["model"][0]  # 机型
-        device_info_dict["lang"] = "" if "lang" not in info_model.keys() else info_model["lang"][0]  #语言
-        device_info_dict["ver_no"] = "" if "ver_no" not in info_model.keys() else info_model["ver_no"][0]  #接口版本号
-        device_info_dict["timestamp"] = 0 if "timestamp" not in info_model.keys() else int(info_model["timestamp"][0])  # 时间搓毫秒
-        device_info_dict["signature_md5"] = "" if "signature_md5" not in info_model.keys() else info_model["signature_md5"][0]  # 签名md5
+        clientheaderinfo_string = self.request.headers._dict.get("Clientheaderinfo")
+        if clientheaderinfo_string:
+            info_model = parse_qs(clientheaderinfo_string)
+            device_info_dict["pid"] = int(info_model["pid"][0])  # 产品标识
+            device_info_dict["chid"] = 0 if "chid" not in info_model.keys() else int(info_model["chid"][0])  # 渠道标识
+            device_info_dict["height"] = 0 if "height" not in info_model.keys() else int(info_model["height"][0])  # 高度
+            device_info_dict["width"] = 0 if "width" not in info_model.keys() else int(info_model["width"][0])  # 宽度
+            device_info_dict["version"] = "" if "version" not in info_model.keys() else info_model["version"][0]  # 客户端版本号
+            device_info_dict["app_version"] = "" if "app_version" not in info_model.keys() else info_model["app_version"][0]  # 小程序版本号
+            device_info_dict["net"] = "" if "net" not in info_model.keys() else info_model["net"][0]  # 网络
+            device_info_dict["model_p"] = "" if "model" not in info_model.keys() else info_model["model"][0]  # 机型
+            device_info_dict["lang"] = "" if "lang" not in info_model.keys() else info_model["lang"][0]  #语言
+            device_info_dict["ver_no"] = "" if "ver_no" not in info_model.keys() else info_model["ver_no"][0]  #接口版本号
+            device_info_dict["timestamp"] = 0 if "timestamp" not in info_model.keys() else int(info_model["timestamp"][0])  # 时间搓毫秒
+            device_info_dict["signature_md5"] = "" if "signature_md5" not in info_model.keys() else info_model["signature_md5"][0]  # 签名md5
         return device_info_dict
 
     def emoji_base64_to_emoji(self, text_str):
@@ -651,13 +679,12 @@ class ClientBaseHandler(FrameBaseHandler):
         for i in text_str:
             list_e.append(i)
         for location, item_emoji in enumerate(text_str):
-            if item_emoji in unicode_codes.UNICODE_EMOJI:
-                bytes_item_emoji = item_emoji.encode("utf-8")
-                emoji_base64 = CryptographyHelper.base64_encrypt(bytes_item_emoji, "utf-8")
+            if item_emoji in unicode_codes.UNICODE_EMOJI["en"]:
+                emoji_base64 = CryptographyHelper.base64_encrypt(item_emoji, "utf-8")
                 list_e[location] = "[em_" + emoji_base64 + "]"
-
         return "".join(list_e)
 
+
 def filter_check_params(must_params=None):
     """
     :description: 参数过滤装饰器 仅限handler使用,
@@ -693,6 +720,60 @@ def filter_check_params(must_params=None):
     return check_params
 
 
+def filter_check_request(check_params=None):
+    """
+    :description: 请求过滤装饰器 仅限handler使用,
+                    提供单用户是否存在对某一接口的达到指定请求数的持续请求的校验
+                    装饰器使用方法:
+                    @client_filter_check_params("param_a,param_b,param_c")  或
+                    @client_filter_check_params(["param_a","param_b,param_c"])
+    :param check_params: 校验参数集合
+    :last_editors: HuangJianYi
+    """
+    def check_request(handler):
+        def wrapper(self, **args):
+            object_id = self.get_open_id()
+            if not object_id:
+                object_id = self.get_user_id()
+
+            if self.request_params and object_id:
+
+                app_id = self.get_app_id()
+                if not app_id:
+                    app_id = self.get_source_app_id()
+
+                finally_check_params = []
+                if type(check_params) == str:
+                    finally_check_params = check_params.split(",")
+                if type(check_params) == list:
+                    finally_check_params = check_params
+                if finally_check_params:
+                    sign_params = {key: self.request_params[key] for key in self.request_params if key in finally_check_params}
+                else:
+                    sign_params = self.request_params
+                redis_init = SevenHelper.redis_init()
+                middle_key = f"{self.__class__.__name__}_{app_id}_{object_id}_{self.get_signature_md5(sign_params)}"
+                if redis_init.get(f"check_request_limit:{middle_key}"):
+                    self.response_json_error("request_error", "请求频繁,请稍后再试")
+                    return
+                cache_key = f"check_request_count:{middle_key}_{str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M'))}"
+                cache_value = redis_init.get(cache_key)
+                if cache_value:
+                    cache_value = int(cache_value)
+                    if cache_value >= 30:
+                        redis_init.set(f"check_request_limit:{middle_key}", 1, 60)
+                        self.response_json_error("request_error", "请求频繁,请稍后再试")
+                        return
+                redis_init.incr(cache_key, 1)
+                redis_init.expire(cache_key, 120)
+
+            return handler(self, **args)
+
+        return wrapper
+
+    return check_request
+
+
 def filter_check_head_sign(is_check=True, no_check_params=None):
     """
     :description: 头部过滤装饰器 仅限handler使用
@@ -795,4 +876,4 @@ def filter_check_params_sign(is_check=True, no_check_params=None):
 
         return wrapper
 
-    return check_params
\ No newline at end of file
+    return check_params
