@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2021-09-27 11:25:17
+@LastEditTime: 2021-10-13 09:42:26
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -185,7 +185,7 @@ class UpdatePrizeOrderSellerRemarkHandler(ClientBaseHandler):
         invoke_result_data = order_base_model.update_prize_order_seller_remark(app_id, prize_order_id, seller_remark)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.response_json_success()
+        return self.response_json_success()
 
 
 class UpdatePrizeOrderStatusHandler(ClientBaseHandler):
@@ -214,7 +214,7 @@ class UpdatePrizeOrderStatusHandler(ClientBaseHandler):
         invoke_result_data = order_base_model.update_prize_order_status(app_id, prize_order_id, order_status, express_company, express_no)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.response_json_success()
+        return self.response_json_success()
 
 
 class ImportPrizeOrderHandler(ClientBaseHandler):
@@ -243,7 +243,7 @@ class ImportPrizeOrderHandler(ClientBaseHandler):
         invoke_result_data = order_base_model.import_prize_order(app_id, act_id, content_type, content, ref_head_name)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.response_json_success()
+        return self.response_json_success()
 
 
 class PrizeOrderExportHandler(ClientBaseHandler):
