@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:25:02
-@LastEditTime: 2021-09-14 19:47:28
+@LastEditTime: 2021-10-13 09:42:48
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -54,7 +54,7 @@ class SavePriceGearHandler(ClientBaseHandler):
         else:
             self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SavePriceGearHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
 
-        self.response_json_success(invoke_result_data.data["new"].id)
+        return self.response_json_success(invoke_result_data.data["new"].id)
 
 
 class PriceGearListHandler(ClientBaseHandler):
@@ -79,7 +79,7 @@ class PriceGearListHandler(ClientBaseHandler):
         page_size = int(self.get_param("page_size", 20))
         is_del = int(self.get_param("is_del", 0))
 
-        self.response_json_success(PriceBaseModel(context=self).get_price_gear_list(app_id, act_id, page_size, page_index,is_del=is_del,is_cache=False))
+        return self.response_json_success(PriceBaseModel(context=self).get_price_gear_list(app_id, act_id, page_size, page_index,is_del=is_del,is_cache=False))
 
 
 class DeletePriceGearHandler(ClientBaseHandler):
@@ -105,7 +105,7 @@ class DeletePriceGearHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.create_operation_log(OperationType.delete.value, "price_gear_tb", "DeletePriceGearHandler", None, price_gear_id)
-        self.response_json_success()
+        return self.response_json_success()
 
 
 class ReviewPriceGearHandler(ClientBaseHandler):
@@ -131,7 +131,7 @@ class ReviewPriceGearHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.create_operation_log(OperationType.review.value, "price_gear_tb", "ReviewPriceGearHandler", None, price_gear_id)
-        self.response_json_success()
+        return self.response_json_success()
 
 
 class CheckPriceGearHandler(ClientBaseHandler):
@@ -160,4 +160,4 @@ class CheckPriceGearHandler(ClientBaseHandler):
         invoke_result_data = price_base_model.check_price_gear(app_id, act_id, price_gear_id, goods_id, sku_id)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.response_json_success()
+        return self.response_json_success()
