@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-10-09 11:32:40
+@LastEditTime: 2021-10-13 09:43:17
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -115,7 +115,7 @@ class SaveActPrizeHandler(ClientBaseHandler):
         else:
             self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SaveActPrizeHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
 
-        self.response_json_success(invoke_result_data.data["new"].id)
+        return self.response_json_success(invoke_result_data.data["new"].id)
 
 
 class ActPrizeListHandler(ClientBaseHandler):
@@ -247,4 +247,4 @@ class ReleaseActPrizeHandler(ClientBaseHandler):
         invoke_result_data = prize_base_model.release_act_prize(app_id, prize_id, is_release)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.response_json_success()
\ No newline at end of file
+        return self.response_json_success()
\ No newline at end of file
