@@ -10,7 +10,7 @@ from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.stat_base_model import *
 
 
-class StatReportListHandler(TaoBaseHandler):
+class StatReportListHandler(ClientBaseHandler):
     """
     :description: 报表数据列表(表格)
     """
@@ -48,7 +48,7 @@ class StatReportListHandler(TaoBaseHandler):
         return stat_report_list
 
 
-class TrendReportListHandler(TaoBaseHandler):
+class TrendReportListHandler(ClientBaseHandler):
     """
     :description: 报表数据列表(趋势图) 
     """
