@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 09:03:41
-@LastEditTime: 2021-09-14 19:48:02
+@LastEditTime: 2021-10-13 09:43:45
 @LastEditors: HuangJianYi
 @Description: 主题皮肤
 """
@@ -24,7 +24,7 @@ class ThemeInfoListHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         theme_base_model = ThemeBaseModel(context=self)
-        self.response_json_success(theme_base_model.get_theme_list(app_id,is_cache=False))
+        return self.response_json_success(theme_base_model.get_theme_list(app_id,is_cache=False))
 
 
 class SkinInfoListHandler(ClientBaseHandler):
@@ -41,7 +41,7 @@ class SkinInfoListHandler(ClientBaseHandler):
         """
         theme_id = int(self.get_param("theme_id", 0))
         theme_base_model = ThemeBaseModel(context=self)
-        self.response_json_success(theme_base_model.get_skin_list(theme_id,is_cache=False))
+        return self.response_json_success(theme_base_model.get_skin_list(theme_id,is_cache=False))
 
 
 class UpdateThemeHandler(ClientBaseHandler):
