@@ -2,18 +2,10 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2021-09-09 19:06:30
+@LastEditTime: 2021-10-08 22:13:25
 @LastEditors: HuangJianYi
 @Description: 
 """
-# -*- coding: utf-8 -*-
-"""
-:Author: HuangJianYi
-:Date: 2020-05-26 11:34:07
-:LastEditTime: 2020-12-07 16:26:12
-:LastEditors: HuangJianYi
-:description: 阿里云存储
-"""
 import oss2
 import os
 
