@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-03-06 23:17:54
-@LastEditTime: 2021-09-29 16:02:41
+@LastEditTime: 2021-10-09 18:21:02
 @LastEditors: HuangJianYi
 :Description: 数据库基础操作类
 """
@@ -35,9 +35,10 @@ class CacheModel(BaseModel):
             dependency_key = "dependency_" + self.table_name.lower()
         return dependency_key
 
-    def __get_cache_key(self, where='', group_by='', order_by='', limit='', params=None):
+    def __get_cache_key(self, field, where='', group_by='', order_by='', limit='', params=None):
         """
         :Description: 获取缓存key
+        :param field: 查询字段
         :param where: 数据库查询条件语句
         :param group_by: GROUP BY 语句
         :param order_by:  ORDER BY 语句
@@ -53,7 +54,7 @@ class CacheModel(BaseModel):
                     params_str += "_" + str(param)
             else:
                 params_str += "_" + str(params)
-        cache_key = str(where + "_" + group_by + "_" + order_by + "_" + limit + params_str).replace(" ", "").lower()
+        cache_key = str(field + "_" + where + "_" + group_by + "_" + order_by + "_" + limit + params_str).replace(" ", "").lower()
         return CryptoHelper.md5_encrypt(cache_key)
         
     def __get_dependency_cache_key(self, dependency_key, cache_key):
@@ -170,7 +171,7 @@ class CacheModel(BaseModel):
         sql = f"SELECT * FROM {self.table_name}{where}{group_by}{order_by}{limit};"
         
         dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "entitylist_" + self.table_name + "_" + self.__get_cache_key(where,group_by,order_by,limit,params)
+        cache_key = "entitylist_" + self.table_name + "_" + self.__get_cache_key('*',where,group_by,order_by,limit,params)
         list_row = self.__get_dependency_cache(dependency_key,cache_key)
         if list_row and config.get_value("is_redis_cache",True) == True:
             if list_row == 'null':
@@ -211,7 +212,7 @@ class CacheModel(BaseModel):
         count_sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by};"
         
         dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "entitypagelist_" + self.table_name + "_" + self.__get_cache_key(where,group_by,order_by,limit,params)
+        cache_key = "entitypagelist_" + self.table_name + "_" + self.__get_cache_key(field,where,group_by,order_by,limit,params)
         page_list = self.__get_dependency_cache(dependency_key,cache_key)
         if page_list and config.get_value("is_redis_cache",True) == True:
             return self._BaseModel__row_entity_list(page_list["data"]),page_list["row_count"]
@@ -249,7 +250,7 @@ class CacheModel(BaseModel):
         sql = f"SELECT * FROM {self.table_name}{where}{group_by}{order_by} LIMIT 1;"
 
         dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "entity_" + self.table_name + "_" + self.__get_cache_key(where,group_by,order_by,'1',params)
+        cache_key = "entity_" + self.table_name + "_" + self.__get_cache_key('*',where,group_by,order_by,'1',params)
         one_row = self.__get_dependency_cache(dependency_key,cache_key)
         if one_row and config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
@@ -274,7 +275,7 @@ class CacheModel(BaseModel):
         sql = f"SELECT * FROM {self.table_name} WHERE {where};"
  
         dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "entityone_" + self.table_name + "_" + self.__get_cache_key(where,'','','',params)
+        cache_key = "entityone_" + self.table_name + "_" + self.__get_cache_key('*',where,'','','',params)
         one_row = self.__get_dependency_cache(dependency_key,cache_key)
         if one_row and config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
@@ -306,7 +307,7 @@ class CacheModel(BaseModel):
         sql = f"SELECT COUNT({field}) AS count FROM {self.table_name}{where}{group_by};"
 
         dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "total_" + self.table_name + "_" + self.__get_cache_key(where,group_by,'','',params)
+        cache_key = "total_" + self.table_name + "_" + self.__get_cache_key(field,where,group_by,'','',params)
         total = self.__get_dependency_cache(dependency_key,cache_key)
         if total and config.get_value("is_redis_cache",True) == True:
             if total == '0':
@@ -347,7 +348,7 @@ class CacheModel(BaseModel):
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by}{limit}"
 
         dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "dict_" + self.table_name + "_" + self.__get_cache_key(where,group_by,order_by,limit,params)
+        cache_key = "dict_" + self.table_name + "_" + self.__get_cache_key(field,where,group_by,order_by,limit,params)
         one_row = self.__get_dependency_cache(dependency_key,cache_key)
         
         if one_row and config.get_value("is_redis_cache",True) == True:
@@ -374,7 +375,7 @@ class CacheModel(BaseModel):
         sql = f"SELECT {field} FROM {self.table_name} WHERE {where};"
 
         dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "dictone_" + self.table_name + "_" + self.__get_cache_key(where,'','','',params)
+        cache_key = "dictone_" + self.table_name + "_" + self.__get_cache_key(field,where,'','','',params)
         one_row = self.__get_dependency_cache(dependency_key,cache_key)
         if one_row and config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
@@ -410,7 +411,7 @@ class CacheModel(BaseModel):
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by}{limit};"
 
         dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "dictlist_" + self.table_name + "_" + self.__get_cache_key(where,group_by,order_by,limit,params)
+        cache_key = "dictlist_" + self.table_name + "_" + self.__get_cache_key(field,where,group_by,order_by,limit,params)
         list = self.__get_dependency_cache(dependency_key,cache_key)
         if list and config.get_value("is_redis_cache",True) == True:
             return list
@@ -445,7 +446,7 @@ class CacheModel(BaseModel):
         count_sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by};"
    
         dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "dictpagelist_" + self.table_name + "_" + self.__get_cache_key(where,group_by,order_by,limit,params)
+        cache_key = "dictpagelist_" + self.table_name + "_" + self.__get_cache_key(field,where,group_by,order_by,limit,params)
         page_list = self.__get_dependency_cache(dependency_key,cache_key)
         if page_list and config.get_value("is_redis_cache",True) == True:
             return page_list["data"],page_list["row_count"]
