@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:55:09
-@LastEditTime: 2021-09-02 17:10:25
+@LastEditTime: 2021-10-19 18:25:27
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -49,6 +49,7 @@ class PrizeOrder:
         self.seller_remark = ""  # 卖家备注
         self.is_free_freight = 0  # 是否包邮
         self.freight_price = 0  # 运费金额
+        self.freight_pay_order_no = ""  # 运费支付单号
         self.create_date = "1900-01-01 00:00:00"  # 创建时间
         self.create_month = 0  # 创建月
         self.create_day = 0  # 创建天
@@ -71,7 +72,7 @@ class PrizeOrder:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'order_no', 'app_id', 'act_id', 'module_id', 'user_id', 'open_id', 'user_nick', 'real_name', 'telephone', 'province', 'city', 'county', 'street', 'address', 'deliver_date', 'express_no', 'express_company', 'order_status', 'buyer_remark', 'seller_remark', 'is_free_freight', 'freight_price', 'create_date', 'create_month', 'create_day', 'sync_status', 'sync_date', 'sync_count', 'sync_result', 'i1', 'i2', 'i3', 'i4', 'i5', 's1', 's2', 's3', 's4', 's5', 'd1', 'd2']
+        return ['id', 'order_no', 'app_id', 'act_id', 'module_id', 'user_id', 'open_id', 'user_nick', 'real_name', 'telephone', 'province', 'city', 'county', 'street', 'address', 'deliver_date', 'express_no', 'express_company', 'order_status', 'buyer_remark', 'seller_remark', 'is_free_freight', 'freight_price', 'freight_pay_order_no', 'create_date', 'create_month', 'create_day', 'sync_status', 'sync_date', 'sync_count', 'sync_result', 'i1', 'i2', 'i3', 'i4', 'i5', 's1', 's2', 's3', 's4', 's5', 'd1','d2']
 
     @classmethod
     def get_primary_key(self):
