@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-11 09:10:33
-@LastEditTime: 2021-09-17 20:04:37
+@LastEditTime: 2021-11-12 09:55:46
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -120,7 +120,7 @@ class FrameBaseModel():
         else:
             return "交易成功"
             
-    def business_process_executing(self,app_id,act_id,module_id,user_id,login_token,handler_name,check_new_user=False,check_user_nick=True,continue_request_expire=5,acquire_lock_name=""):
+    def business_process_executing(self,app_id,act_id,module_id,user_id,login_token,handler_name,check_new_user=False,check_user_nick=True,continue_request_expire=5,acquire_lock_name="",request_limit_num=0,request_limit_time=1):
         """
         :description: 业务执行前事件,核心业务如抽奖、做任务需要调用当前方法
         :param app_id:应用标识
@@ -133,6 +133,8 @@ class FrameBaseModel():
         :param check_user_nick:是否校验昵称为空
         :param continue_request_expire:连续请求过期时间，为0不进行校验，单位秒 
         :param acquire_lock_name:分布式锁名称，为空则不开启分布式锁校验功能
+        :param request_limit_num:请求限制数；0不限制
+        :param request_limit_time:请求限制时间；默认1秒
         :return:
         :last_editors: HuangJianYi
         """
@@ -151,6 +153,15 @@ class FrameBaseModel():
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message = f"对不起,请{continue_request_expire}秒后再试"
                 return invoke_result_data
+        request_queue_name = ""
+        if request_limit_num > 0  and request_limit_time > 0:
+            request_queue_name = f"request_queue:{handler_name}_{act_id}_{module_id}"
+            if SevenHelper.redis_check_llen(request_queue_name,request_limit_num) == True:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "concurrent"
+                invoke_result_data.error_message = "当前人数过多,请稍后再试"
+                return invoke_result_data
+            SevenHelper.redis_lpush(request_queue_name,user_id,request_limit_time)
 
         act_info_model = ActInfoModel(context=self.context)
         act_info_dict = act_info_model.get_cache_dict_by_id(act_id,dependency_key=f"act_info:actid_{act_id}")
@@ -227,11 +238,8 @@ class FrameBaseModel():
              invoke_result_data.error_code = "error"
              invoke_result_data.error_message = "已在另一台设备登录,无法操作"
              return invoke_result_data
-        invoke_result_data.data = {}
-        invoke_result_data.data["act_info_dict"] = act_info_dict
-        invoke_result_data.data["act_module_dict"] = act_module_dict
-        invoke_result_data.data["user_info_dict"] = user_info_dict
         #分布式锁名称存在才进行校验
+        identifier = ""
         if acquire_lock_name:
             acquire_lock_status, identifier = SevenHelper.redis_acquire_lock(acquire_lock_name)
             if acquire_lock_status == False:
@@ -239,10 +247,16 @@ class FrameBaseModel():
                 invoke_result_data.error_code = "acquire_lock"
                 invoke_result_data.error_message = "系统繁忙,请稍后再试"
                 return invoke_result_data
-            invoke_result_data.data["identifier"] = identifier
+
+        invoke_result_data.data = {}
+        invoke_result_data.data["act_info_dict"] = act_info_dict
+        invoke_result_data.data["act_module_dict"] = act_module_dict
+        invoke_result_data.data["user_info_dict"] = user_info_dict
+        invoke_result_data.data["identifier"] = identifier
+        invoke_result_data.data["request_queue_name"] = request_queue_name
         return invoke_result_data
     
-    def business_process_executed(self,act_id,module_id,user_id,handler_name,acquire_lock_name="",identifier=""):
+    def business_process_executed(self,act_id,module_id,user_id,handler_name,acquire_lock_name="",identifier="",request_queue_name=""):
         """
         :description: 业务执行后事件，调用了业务执行前事件需要调用当前方法
         :param act_id:活动标识
@@ -251,12 +265,16 @@ class FrameBaseModel():
         :param handler_name:接口名称
         :param acquire_lock_name:分布式锁名称
         :param identifier:分布式锁标识
+        :param request_queue_name:请求队列名称
         :return:
         :last_editors: HuangJianYi
         """
         SevenHelper.redis_init().delete(f"request_business_executing:{handler_name}_{act_id}_{module_id}_{user_id}")
         if acquire_lock_name and identifier:
             SevenHelper.redis_release_lock(acquire_lock_name,identifier)
+        if request_queue_name:
+            SevenHelper.redis_lpop(request_queue_name)
+        
 
 
         
