@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-04 13:41:15
-@LastEditTime: 2021-09-17 20:11:00
+@LastEditTime: 2021-10-09 10:57:45
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -57,7 +57,7 @@ class PrizeBaseModel():
                 return None
         return act_prize_dict
 
-    def get_act_prize_list(self,app_id,act_id,module_id,prize_name,ascription_type,is_del,page_size,page_index,is_cache=True):
+    def get_act_prize_list(self,app_id,act_id,module_id,prize_name,ascription_type,is_del,page_size,page_index,order_by="sort_index desc,id asc",condition="",params=[],is_cache=True):
         """
         :description: 获取活动奖品列表
         :param app_id: 应用标识
@@ -68,30 +68,35 @@ class PrizeBaseModel():
         :param is_del：是否回收站1是0否
         :param page_size: 条数
         :param page_index: 页数
+        :param order_by：排序
+        :param condition：条件
+        :param params：参数化数组
         :param is_cache: 是否缓存
         :return: 
         :last_editors: HuangJianYi
         """
-        order_by = "sort_index desc,id asc"
-        condition = "app_id=%s and act_id=%s"
-        params = [app_id,act_id]
+        where = "app_id=%s AND act_id=%s"
+        params_list = [app_id,act_id]
+        if condition:
+            where += " AND " + condition
+            params_list.extend(params)
         if ascription_type !=0:
-            condition += " and ascription_type=%s"
-            params.append(is_del)
+            where += " and ascription_type=%s"
+            params_list.append(is_del)
         if is_del !=-1:
-            condition += " and is_del=%s"
-            params.append(is_del)
+            where += " and is_del=%s"
+            params_list.append(is_del)
         if module_id !=0:
-            condition += " and module_id=%s"
-            params.append(module_id)
+            where += " and module_id=%s"
+            params_list.append(module_id)
         if prize_name:
-            condition += " and prize_name=%s"
-            params.append(prize_name)
+            where += " and prize_name=%s"
+            params_list.append(prize_name)
         act_prize_model = ActPrizeModel(context=self.context)
         if is_cache:
-            page_list, total = act_prize_model.get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params,dependency_key=f"act_prize_list:actid_{act_id}")
+            page_list, total = act_prize_model.get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list,dependency_key=f"act_prize_list:actid_{act_id}")
         else:
-            page_list, total = act_prize_model.get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params)    
+            page_list, total = act_prize_model.get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list)    
         return page_list, total
 
     def save_act_prize(self,app_id,act_id,module_id,prize_id,prize_name,prize_title,prize_pic,prize_detail_json,goods_id,goods_code,goods_code_list,goods_type,prize_type,prize_price,probability,chance,prize_limit,is_prize_notice,surplus,is_surplus,lottery_type,tag_name,tag_id,is_sku,sku_json,sort_index,is_release,ascription_type=0,i1=0,i2=0,i3=0,i4=0,i5=0,s1='',s2='',s3='',s4='',s5='',d1='',d2=''):
