@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2021-10-12 17:55:48
+@LastEditTime: 2021-11-02 18:49:52
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -16,6 +16,7 @@ from seven_cloudapp_frame.models.db_models.user.user_black_model import *
 from seven_cloudapp_frame.models.db_models.act.act_module_model import *
 from seven_cloudapp_frame.models.db_models.act.act_prize_model import *
 from seven_cloudapp_frame.models.db_models.prize.prize_roster_model import *
+from seven_cloudapp_frame.models.db_models.user.user_address_model import *
 
 class UserBaseModel(FrameBaseModel):
     """
@@ -177,7 +178,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_message = "参数不能为空或等于0"
             return invoke_result_data
 
-        acquire_lock_name = f"get_or_add_user_by_openid:{app_id}_{open_id}"
+        acquire_lock_name = f"save_user_by_openid:{app_id}_{open_id}"
         acquire_lock_status, identifier = SevenHelper.redis_acquire_lock(acquire_lock_name)
         if acquire_lock_status == False:
             invoke_result_data.success = False
@@ -422,7 +423,8 @@ class UserBaseModel(FrameBaseModel):
             self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
 
         except Exception as ex:
-            db_transaction.rollback_transaction()
+            if db_transaction.is_transaction == True:
+                db_transaction.rollback_transaction()
             self.context.logging_link_error("【更新用户状态黑名单】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
@@ -711,4 +713,106 @@ class UserBaseModel(FrameBaseModel):
             result = False
         return result
  
-    
\ No newline at end of file
+    def get_user_address_list(self, app_id, act_id, user_id,is_cache=True):
+        """
+        :description: 获取用户地址列表
+        :param app_id：应用标识
+        :param act_id：活动标识
+        :param tb_user_id：用户标识
+        :param is_cache：是否缓存
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        condition = "act_id=%s AND user_id=%s"
+        params = [act_id, user_id]
+        if app_id:
+            condition += " AND app_id=%s"
+            params.append(app_id)
+        user_address_list = []
+        user_address_model = UserAddressModel(context=self.context)
+        if is_cache:
+            user_address_list = user_address_model.get_cache_dict_list(condition, params=params, dependency_key=f"user_address_list:actid_{act_id}_userid_{user_id}")
+        else:
+            user_address_list = user_address_model.get_dict_list(condition, params=params)
+
+        return user_address_list
+
+    def save_user_address(self, app_id, act_id, user_id, open_id, user_address_id, real_name, telephone, province, city, county, street, address, is_default):
+        """
+        :description: 保存用户地址
+        :param app_id：应用标识
+        :param act_id：活动标识
+        :param user_id：用户标识
+        :param open_id：open_id
+        :param open_id：open_id
+        :param user_address_id:用户地址标识
+        :param real_name：真实姓名
+        :param telephone：手机号码
+        :param province：省
+        :param city：市
+        :param county：区
+        :param street：街道
+        :param address：地址
+        :param is_default：是否默认地址（1是0否）
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        if not act_id or (not user_id and not open_id):
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "param_error"
+            invoke_result_data.error_message = "参数不能为空或等于0"
+            return invoke_result_data
+        user_info_dict = self.get_user_info_dict(act_id,user_id,open_id)
+        if not user_info_dict:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = "用户信息不存在"
+            return invoke_result_data
+        if user_info_dict["app_id"] != app_id:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = "非法操作"
+            return invoke_result_data
+
+        user_address_model = UserAddressModel()
+        if user_address_id > 0:
+            user_address = user_address_model.get_entity("id=%s", params=[user_address_id])
+            if not user_address:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message = "地址信息不存在"
+                return invoke_result_data
+            user_address.real_name = real_name
+            user_address.telephone = telephone
+            user_address.province = province
+            user_address.city = city
+            user_address.county = county
+            user_address.street = street
+            user_address.address = address
+            user_address_model.update_entity(user_address, "real_name,telephone,province,city,county,street,address")
+        else:
+            user_address = UserAddress()
+            user_address.app_id = app_id
+            user_address.act_id = act_id
+            user_address.user_id = user_id
+            user_address.open_id = open_id
+            user_address.real_name = real_name
+            user_address.telephone = telephone
+            user_address.province = province
+            user_address.city = city
+            user_address.county = county
+            user_address.street = street
+            user_address.address = address
+            user_address.is_default = is_default
+            user_address.create_date = SevenHelper.get_now_datetime()
+            user_address_model.add_entity(user_address)
+        user_address_model.delete_dependency_key(f"user_address_list:actid_{act_id}_userid_{user_id}")
+        return invoke_result_data
+
+
+    
+
+
+
+    
